@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import sys
+from collections import OrderedDict
 from pathlib import Path
 
 PACKAGE_PATH = Path(__file__).resolve().parents[1]
@@ -8,7 +9,7 @@ sys.path.append(str(PACKAGE_PATH))
 
 from pde import environment
 
-env = environment()
+env = environment(OrderedDict)
 
 for category, data in env.items():
     if hasattr(data, 'items'):
